<?php
defined('B_PROLOG_INCLUDED') || die;

use Academy\CrmStores\BizProc\StoreDocument;
use Bitrix\Main\Config\Option;
use Bitrix\Main\Grid\Panel\Snippet;
use Bitrix\Main\Loader;
use Bitrix\Main\Localization\Loc;
use Bitrix\Main\Page\Asset;
use Bitrix\Main\Web\Json;

/** @var CBitrixComponentTemplate $this */

if (!Loader::includeModule('crm')) {
    ShowError(Loc::getMessage('CRMSTORES_NO_CRM_MODULE'));
    return;
}

CJSCore::Init('bp_starter');

$asset = Asset::getInstance();
$asset->addJs('/bitrix/js/crm/interface_grid.js');

$gridManagerId = $arResult['GRID_ID'] . '_MANAGER';

$rows = array();
foreach ($arResult['STORES'] as $store) {

    $viewUrl = CComponentEngine::makePathFromTemplate(
        $arParams['URL_TEMPLATES']['DETAIL'],
        array('STORE_ID' => $store['ID'])
    );
    $editUrl = CComponentEngine::makePathFromTemplate(
        $arParams['URL_TEMPLATES']['EDIT'],
        array('STORE_ID' => $store['ID'])
    );

    $deleteUrlParams = http_build_query(array(
        'action_button_' . $arResult['GRID_ID'] => 'delete',
        'ID' => array($store['ID']),
        'sessid' => bitrix_sessid()
    ));
    $deleteUrl = $arParams['SEF_FOLDER'] . '?' . $deleteUrlParams;

    $rowActions = array(
        array(
            'TITLE' => Loc::getMessage('CRMSTORES_ACTION_VIEW_TITLE'),
            'TEXT' => Loc::getMessage('CRMSTORES_ACTION_VIEW_TEXT'),
            'ONCLICK' => sprintf('BX.Crm.Page.open(%s)', Json::encode($viewUrl)),
            'DEFAULT' => true
        ),
        array(
            'TITLE' => Loc::getMessage('CRMSTORES_ACTION_EDIT_TITLE'),
            'TEXT' => Loc::getMessage('CRMSTORES_ACTION_EDIT_TEXT'),
            'ONCLICK' => sprintf('BX.Crm.Page.open(%s)', Json::encode($editUrl)),
        ),
        array(
            'TITLE' => Loc::getMessage('CRMSTORES_ACTION_DELETE_TITLE'),
            'TEXT' => Loc::getMessage('CRMSTORES_ACTION_DELETE_TEXT'),
            'ONCLICK' => sprintf(
                'BX.CrmUIGridExtension.processMenuCommand(%s, BX.CrmUIGridMenuCommand.remove, { pathToRemove: %s })',
                Json::encode($gridManagerId),
                Json::encode($deleteUrl)
            ),
        )
    );

    if (!empty($arResult['WORKFLOW_TEMPLATES'])) {
        $startWorkflowActions = array();
        foreach ($arResult['WORKFLOW_TEMPLATES'] as $workflowTemplate) {
            $starterParams = array(
                'moduleId' => 'academy.crmstores',
                'entity' => StoreDocument::class,
                'documentType' => 'store',
                'documentId' => $store['ID'],
                'templateId' => $workflowTemplate['ID'],
                'templateName' => $workflowTemplate['NAME'],
                'hasParameters' => $workflowTemplate['HAS_PARAMETERS']
            );
            $callback = sprintf(
                'function () { BX.Main.gridManager.reload(%s); }',
                Json::encode($arResult['GRID_ID'])
            );
            $startWorkflowActions[] = array(
                'TITLE' => $workflowTemplate['DESCRIPTION'],
                'TEXT' => $workflowTemplate['NAME'],
                'ONCLICK' => sprintf(
                    'BX.Bizproc.Starter.singleStart(%s, %s)',
                    Json::encode($starterParams),
                    $callback
                )
            );
        }

        $rowActions[] = array('SEPARATOR' => true);
        $rowActions[] = array(
            'TITLE' => Loc::getMessage('CRMSTORES_ACTION_START_WORKFLOW_TITLE'),
            'TEXT' => Loc::getMessage('CRMSTORES_ACTION_START_WORKFLOW_TEXT'),
            'MENU' => $startWorkflowActions
        );
    }

    $rows[] = array(
        'id' => $store['ID'],
        'actions' => $rowActions,
        'data' => $store,
        'columns' => array(
            'ID' => $store['ID'],
            'NAME' => '<a href="' . $viewUrl . '" target="_self">' . $store['NAME'] . '</a>',
            'ASSIGNED_BY' => empty($store['ASSIGNED_BY']) ? '' : CCrmViewHelper::PrepareUserBaloonHtml(
                array(
                    'PREFIX' => "STORE_{$store['ID']}_RESPONSIBLE",
                    'USER_ID' => $store['ASSIGNED_BY_ID'],
                    'USER_NAME'=> CUser::FormatName(CSite::GetNameFormat(), $store['ASSIGNED_BY']),
                    'USER_PROFILE_URL' => CComponentEngine::makePathFromTemplate(
                        Option::get('intranet', 'path_user', '', SITE_ID),
                        array('USER_ID' => $store['ASSIGNED_BY_ID'])
                    )
                )
            ),
            'ADDRESS' => $store['ADDRESS'],
        )
    );
}

$snippet = new Snippet();

$APPLICATION->IncludeComponent(
    'bitrix:crm.interface.grid',
    'titleflex',
    array(
        'GRID_ID' => $arResult['GRID_ID'],
        'HEADERS' => $arResult['HEADERS'],
        'ROWS' => $rows,
        'PAGINATION' => $arResult['PAGINATION'],
        'SORT' => $arResult['SORT'],
        'FILTER' => $arResult['FILTER'],
        'FILTER_PRESETS' => $arResult['FILTER_PRESETS'],
        'IS_EXTERNAL_FILTER' => false,
        'ENABLE_LIVE_SEARCH' => $arResult['ENABLE_LIVE_SEARCH'],
        'DISABLE_SEARCH' => $arResult['DISABLE_SEARCH'],
        'ENABLE_ROW_COUNT_LOADER' => true,
        'AJAX_ID' => '',
        'AJAX_OPTION_JUMP' => 'N',
        'AJAX_OPTION_HISTORY' => 'N',
        'AJAX_LOADER' => null,
        'ACTION_PANEL' => array(
            'GROUPS' => array(
                array(
                    'ITEMS' => array(
                        $snippet->getRemoveButton(),
                        $snippet->getForAllCheckbox(),
                    )
                )
            )
        ),
        'EXTENSION' => array(
            'ID' => $gridManagerId,
            'CONFIG' => array(
                'ownerTypeName' => 'STORE',
                'gridId' => $arResult['GRID_ID'],
                'serviceUrl' => $arResult['SERVICE_URL'],
            ),
            'MESSAGES' => array(
                'deletionDialogTitle' => Loc::getMessage('CRMSTORES_DELETE_DIALOG_TITLE'),
                'deletionDialogMessage' => Loc::getMessage('CRMSTORES_DELETE_DIALOG_MESSAGE'),
                'deletionDialogButtonTitle' => Loc::getMessage('CRMSTORES_DELETE_DIALOG_BUTTON'),
            )
        ),
    ),
    $this->getComponent(),
    array('HIDE_ICONS' => 'Y',)
);