<?php
defined('B_PROLOG_INCLUDED') || die;

use Academy\CrmStores\Entity\StoreTable;
use Academy\CrmStores\UserType\StoreBinding;
use Bitrix\Main\Application;
use Bitrix\Main\Config\Option;
use Bitrix\Main\EventManager;
use Bitrix\Main\Loader;
use Bitrix\Main\Localization\Loc;
use Bitrix\Main\ModuleManager;

class academy_crmstores extends CModule
{
    const MODULE_ID = 'academy.crmstores';
    var $MODULE_ID = self::MODULE_ID;
    var $MODULE_VERSION;
    var $MODULE_VERSION_DATE;
    var $MODULE_NAME;
    var $MODULE_DESCRIPTION;
    var $MODULE_CSS;
    var $strError = '';

    function __construct()
    {
        $arModuleVersion = array();
        include(dirname(__FILE__) . '/version.php');
        $this->MODULE_VERSION = $arModuleVersion['VERSION'];
        $this->MODULE_VERSION_DATE = $arModuleVersion['VERSION_DATE'];

        $this->MODULE_NAME = Loc::getMessage('ACADEMY_CRMSTORES.MODULE_NAME');
        $this->MODULE_DESCRIPTION = Loc::getMessage('ACADEMY_CRMSTORES.MODULE_DESC');

        $this->PARTNER_NAME = Loc::getMessage('ACADEMY_CRMSTORES.PARTNER_NAME');
        $this->PARTNER_URI = Loc::getMessage('ACADEMY_CRMSTORES.PARTNER_URI');
    }

    function DoInstall()
    {
        ModuleManager::registerModule(self::MODULE_ID);

        $this->InstallEvents();
        $this->InstallDB();
        $this->InstallFiles();
    }

    function InstallDB()
    {
        global $USER_FIELD_MANAGER;

        Loader::includeModule('academy.crmstores');

        $db = Application::getConnection();

        $storeEntity = StoreTable::getEntity();
        if (!$db->isTableExists($storeEntity->getDBTableName())) {
            $storeEntity->createDbTable();
        }

        $dealUserFields = $USER_FIELD_MANAGER->GetUserFields('CRM_DEAL');
        if (!array_key_exists('UF_STORE', $dealUserFields)) {
            $userTypeEntity = new CUserTypeEntity();
            $userTypeEntity->Add(array(
                'ENTITY_ID' => 'CRM_DEAL',
                'FIELD_NAME' => 'UF_STORE',
                'USER_TYPE_ID' => StoreBinding::USER_TYPE_ID,
                'MULTIPLE' => 'N',
                'MANDATORY' => 'N',
                'SHOW_FILTER' => 'I',
                'SHOW_IN_LIST' => '',
                'EDIT_IN_LIST' => '',
                'IS_SEARCHABLE' => 'Y',
                'SETTINGS' => array(),
                'EDIT_FORM_LABEL' => array(
                    'ru' => 'Торговая точка',
                    'en' => 'Store',
                ),
                'LIST_COLUMN_LABEL' => array(
                    'ru' => 'Торговая точка',
                    'en' => 'Store',
                ),
                'LIST_FILTER_LABEL' => array(
                    'ru' => 'Торговая точка',
                    'en' => 'Store',
                ),
                'HELP_MESSAGE' => array(
                    'ru' => '',
                    'en' => '',
                ),
            ));
        }
    }

    function InstallFiles()
    {
        $documentRoot = Application::getDocumentRoot();

        CopyDirFiles(
            __DIR__ . '/files/admin',
            $documentRoot . '/bitrix/admin',
            true,
            true
        );

        CopyDirFiles(
            __DIR__ . '/files/components',
            $documentRoot . '/local/components',
            true,
            true
        );

        CopyDirFiles(
            __DIR__ . '/files/pub/crm',
            $documentRoot . '/crm',
            true,
            true
        );

        CUrlRewriter::Add(array(
            'CONDITION' => '#^/crm/stores/#',
            'RULE' => '',
            'ID' => 'academy.crmstores:stores',
            'PATH' => '/crm/stores/index.php',
        ));
    }

    function InstallEvents()
    {
        $eventManager = EventManager::getInstance();

        $eventManager->registerEventHandlerCompatible(
            'crm',
            'OnAfterCrmControlPanelBuild',
            self::MODULE_ID,
            '\Academy\CrmStores\Handler\CrmMenu',
            'addStores'
        );

        $eventManager->registerEventHandlerCompatible(
            'main',
            'OnUserTypeBuildList',
            self::MODULE_ID,
            '\Academy\CrmStores\UserType\StoreBinding',
            'GetUserTypeDescription'
        );
    }

    function DoUninstall()
    {
        $this->UnInstallFiles();
        $this->UnInstallDB();
        $this->UnInstallEvents();

        ModuleManager::unRegisterModule(self::MODULE_ID);
    }

    function UnInstallEvents()
    {
        $eventManager = EventManager::getInstance();

        $eventManager->unRegisterEventHandler(
            'crm',
            'OnAfterCrmControlPanelBuild',
            self::MODULE_ID,
            '\Academy\CrmStores\Handler\CrmMenu',
            'addStores'
        );

        $eventManager->unRegisterEventHandler(
            'main',
            'OnUserTypeBuildList',
            self::MODULE_ID,
            '\Academy\CrmStores\UserType\StoreBinding',
            'GetUserTypeDescription'
        );
    }

    function UnInstallFiles()
    {
        DeleteDirFilesEx('/crm/stores');
        DeleteDirFilesEx('/local/components/academy.crmstores');
        DeleteDirFilesEx('/bitrix/admin/academy.crmstores_bizproc_activity_settings.php');
        DeleteDirFilesEx('/bitrix/admin/academy.crmstores_bizproc_selector.php');
        DeleteDirFilesEx('/bitrix/admin/academy.crmstores_bizproc_wf_settings.php');

        CUrlRewriter::Delete(array(
            'ID' => 'academy.crmstores:stores',
            'PATH' => '/crm/stores/index.php',
        ));
    }

    function UnInstallDB()
    {
        // Не существенно в данном примере.
    }
}